@@ -1,6 +1,5 @@
 from __future__ import absolute_import
 
-import os
 import sys
 import io
 import collections
@@ -8,15 +7,23 @@ import contextlib
 
 SavedIO = collections.namedtuple('SavedIO', 'stdout stderr')
 
+text_type = __builtins__.get('unicode', str)
+
+class TextIO(io.StringIO):
+	def write(self, data):
+		if not isinstance(data, text_type):
+			data = text_type(data, getattr(self, '_encoding', 'UTF-8'), 'replace')
+		io.StringIO.write(self, data)
+
 @contextlib.contextmanager
 def capture_stdio():
-	sys_stdout, sys.stdout = sys.stdout, io.BytesIO()
-	sys_stderr, sys.stderr = sys.stderr, io.BytesIO()
+	sys_stdout, sys.stdout = sys.stdout, TextIO()
+	sys_stderr, sys.stderr = sys.stderr, TextIO()
 	try:
 		yield SavedIO(sys.stdout, sys.stderr)
 	finally:
 		sys.stdout = sys_stdout
-		sys.stderr = sys.stderr
+		sys.stderr = sys_stderr
 
 @contextlib.contextmanager
 def replace_sysargv(params):
